@@ -9,7 +9,7 @@
 //
 //-----------------------------------------------------------------------------
 // LICENSE
-// (c) 2023, Steinberg Media Technologies GmbH, All Rights Reserved
+// (c) 2024, Steinberg Media Technologies GmbH, All Rights Reserved
 //-----------------------------------------------------------------------------
 // Redistribution and use in source and binary forms, with or without modification,
 // are permitted provided that the following conditions are met:
@@ -404,8 +404,7 @@ void WindowController::onContentScaleFactorChanged (IWindow& w, float newScaleFa
 {
 	SMTG_DBPRT1 ("onContentScaleFactorChanged called (%p)\n", (void*)&w);
 
-	FUnknownPtr<IPlugViewContentScaleSupport> css (plugView);
-	if (css)
+	if (auto css = U::cast<IPlugViewContentScaleSupport> (plugView))
 	{
 		css->setContentScaleFactor (newScaleFactor);
 	}
