@@ -9,7 +9,7 @@
 //
 //-----------------------------------------------------------------------------
 // LICENSE
-// (c) 2023, Steinberg Media Technologies GmbH, All Rights Reserved
+// (c) 2024, Steinberg Media Technologies GmbH, All Rights Reserved
 //-----------------------------------------------------------------------------
 // Redistribution and use in source and binary forms, with or without modification,
 // are permitted provided that the following conditions are met:
@@ -167,6 +167,9 @@ protected:
 
 	bool mBypass {false};
 	bool mSetActiveCalled {false};
+	bool mCheckGetLatencyCall {true};
+	bool mGetLatencyCalled {false};
+	bool mGetLatencyCalledAfterSetActive {false};
 };
 
 //------------------------------------------------------------------------
